# Changelog

<!--next-version-placeholder-->

## v0.1.5 (2023-11-15)
### Fix
* Increased download chunk size to speed up big downloads ([`f47a29e`](https://github.com/robinvandernoord/drive-in/commit/f47a29e4a9bbb9881d3d019293da410ed468ca64))

## v0.1.4 (2023-11-15)
### Fix
* Requests resp.json() now throws a custom error :/ ([`5485d6d`](https://github.com/robinvandernoord/drive-in/commit/5485d6d4c30063e7151c135f28dab22fa6fda06d))

## v0.1.3 (2023-10-02)
### Fix
* Make progress bar on download display as MBs instead of bytes ([`dd84636`](https://github.com/robinvandernoord/drive-in/commit/dd846368289c0b518ba2ea572dd8e7ac37479dcd))

## v0.1.2 (2023-09-28)
### Fix
* Add py.typed file to indicate typing ([`8c338aa`](https://github.com/robinvandernoord/drive-in/commit/8c338aa5c8ca3de0c5762fff111833acf5e3af46))

## v0.1.1 (2023-09-28)
### Documentation
* Fixed su6 action badge ([`7ac72c3`](https://github.com/robinvandernoord/drive-in/commit/7ac72c3f1708f33d97a5859690b3f213e77fd2aa))

## v0.1.0 (2023-09-28)
### Feature
* Download should now work as well ([`530a237`](https://github.com/robinvandernoord/drive-in/commit/530a2376447d064b95ff1422d15e4c70951843ba))
* Boilerplate ([`ebcce5d`](https://github.com/robinvandernoord/drive-in/commit/ebcce5d26dec05b5632047fd150136fa8e71df38))

### Documentation
* Minor improvements ([`a61db1e`](https://github.com/robinvandernoord/drive-in/commit/a61db1e2952737fd22893a62163d03f7faef6888))
* Exlained features and limitations ([`4e6d1c9`](https://github.com/robinvandernoord/drive-in/commit/4e6d1c92e56fb4c8c81907ab670342a67af1598d))
* Added short description ([`6b87c36`](https://github.com/robinvandernoord/drive-in/commit/6b87c36597c3517b07e0e6c013bc7ad582febff0))
